<?php

namespace Controller;

use Zeedhi\Framework\DataSource\Manager;
use Service\DeleteCascadeService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class GoalNotifications extends Crud {

    protected $dataSourceName = 'goalNotifications';

    /** @var \Service\Goals $goalsService */
    protected $goalsService;
    /** @var \Service\widget $viewService */
    protected $viewService;
    /** @var \Service\widget $goalNotificationsService */
    protected $goalNotificationsService;

    public function __construct(Manager $organizationMongoManager, DeleteCascadeService $deleteCascadeService,
                                $goalsService, $goalNotificationsService, $viewService) {
        parent::__construct($organizationMongoManager, $deleteCascadeService);
        $this->goalsService = $goalsService;
        $this->viewService = $viewService;
        $this->goalNotificationsService = $goalNotificationsService;
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $request = $this->buildDataSetIfRow($request);
            $notification = $request->getDataSet()->getRows()[0];
            $notification = $this->goalNotificationsService->setNotificationNextDate($notification);
            $this->goalNotificationsService->saveNotification($notification);
            $response->addDataSet(new DataSet('notifications', array($notification)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 0));
        }
    }

    public function getGoalsInfo(DTO\Request\Row $request, DTO\Response $response){
        try {
            $dataSourceId = $request->getRow()['dataSourceId'];
            $notifications = $this->getGoalNotifications($dataSourceId, $response);
            $goals = $this->getGoalsByNotifications($notifications, $response);
            $this->getViewsByGoals($goals, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 0));
        }
    }

    protected function getGoalNotifications($dataSourceId, &$response) {
        $notifications = $this->goalNotificationsService->getGoalNotificationByDataSourceId($dataSourceId);
        $response->addDataSet(new DataSet('notifications', $notifications));
        return $notifications;
    }

    protected function getGoalsByNotifications($goalNotifications, &$response) {
        $goalIds = array();
        foreach ($goalNotifications as $notification) {
            array_push($goalIds, $notification['goalId']);
        }

        $goals =  $this->goalsService->getGoalsByIds($goalIds);
        $response->addDataSet(new DataSet('goals', $goals));
        return $goals;
    }

    protected function getViewsByGoals($goals, &$response) {
        $viewIds = array();
        foreach ($goals as $goal) {
            array_push($viewIds, $goal['viewId']);
        }

        $views = $this->viewService->getManyWidgetsById($viewIds);
        $response->addDataSet(new DataSet('views', $views));
    }
}
